#include "armv10_std.h"
#include "spi1.h"
#include "enc28j60.h"

#define ENC28J60_CS  *((volatile unsigned long *)(BITBAND_PERI(GPIOA_ODR,4)))
char uart_buffer[25];
unsigned char enc28j60CurrentBank=0x00;
unsigned short NextPacketPtr;
unsigned char hilf=0x00;
unsigned char real_address=0x00;

 
/*--------------------Initialisierung des ENC28J60--------------------*/
void enc28j60Init()
{
	enc28j60SysReset();	//System-Reset des ENC28J60
	
	do
	{
		enc28j60Read(ESTAT, &hilf);
	}
	while(hilf & ESTAT_CLKRDY==0);	//ist Hardware des ENC28J60 schon bereit?	

	//---Bank0-Einstellungen: 
	
	NextPacketPtr=RXSTART_INIT;					//setzen der Startadresse fr Empfangsbufferspeicher
	enc28j60Write(ERXSTL, RXSTART_INIT&0xff);
	enc28j60Write(ERXSTH, RXSTART_INIT>>8);

	enc28j60Write(ERXRDPTL,	RXSTART_INIT&0xff);	 //Setzen des Startpointers fr den Empfang
	enc28j60Write(ERXRDPTH, RXSTART_INIT>>8);
	
	enc28j60Write(ERXNDL, RXSTOP_INIT&0xff);   //setzen der Stopadresse fr Empfangsbufferspeicher
	enc28j60Write(ERXNDH, RXSTOP_INIT>>8);

	enc28j60Write(ETXSTL, TXSTART_INIT&0xff);	//setzen der Startadresse fr Sendebufferspeicher
	enc28j60Write(ETXSTH, TXSTART_INIT>>8);

	enc28j60Write(ETXNDL, TXSTOP_INIT&0xff);  //setzen der Stopadresse fr den Sendebufferspeicher
	enc28j60Write(ETXNDH, TXSTOP_INIT>>8);

	enc28j60Write(ERXFCON, 0x00); // Ethernet Receive Filter deaktivieren

	//---Bank2-Einstellungen:

	enc28j60Write(MACON1, MACON1_MARXEN|MACON1_TXPAUS|MACON1_RXPAUS);	//Paketempfang erlauben/bentigt fr FullDuplex/deto/Pause Control Frame erlauben(Flow Control)
	
	enc28j60Read(MACON3, &hilf);							//Inhalt von MACON3 lesen
	hilf |= MACON3_PADCFG0|MACON3_TXCRCEN|MACON3_FRMLNEN;	//zu kurze Pakete automatisch auffllen/CRC automatisch anhngen/type-lenght berprfen
	enc28j60Write(MACON3, hilf);							//Verndern von MACON3

	enc28j60Read(MACON4, &hilf);		  // Inhalt von MACON4 lesen
	hilf |= MACON4_DEFER;				  // Defer_bit setzen fr IEEE 802.3 Standard
	enc28j60Write(MACON4, hilf);	      // Verndern von MACON4

	enc28j60Write(MAIPGL, 0x12);				//"Inter-Frame Gap" fr Non-Back-to-Back auf "Standard fr Half-Duplex" laut Datenblatt S.34
	enc28j60Write(MAIPGH, 0x0C);

	enc28j60Write(MABBIPG, 0x12);				//"Inter-Frame Gap" fr Back-toBack auf "Standard fr Half-Duplex" laut Datenblatt S.34

	enc28j60Write(MAMXFLL, MAX_FRAMELEN&0xff);	//Maximale Paketlnge festlegen (Senden und Empfangen)
	enc28j60Write(MAMXFLH, MAX_FRAMELEN>>8);

	enc28j60WritePhyReg(PHCON2, PHCON2_HDLDIS);	//"No loopback" fr gesendete Daten einstellen

	enc28j60SelBank(0x00);			//auf Bank 0 schalten

	enc28j60Read(EIE, &hilf);		//Inhalt von EIE lesen
	hilf |= EIE_INTIE|EIE_PKTIE;		//Interrupts erlauben/Interrupt bei Empfangenen Paketen/Gloable Interrupts
	enc28j60Write(EIE, hilf);		//Verndern von EIE

	enc28j60Read(ECON1, &hilf);		//Inhalt von ECON1 lesen
	hilf |= ECON1_RXEN;				//Paketempfang erlauben
	enc28j60Write(ECON1, hilf);		//Verndern von ECON1

	enc28j60WritePhyReg(PHLCON,0x0240);	// LEDs von Ethernet konfigurieren
}

/*--------------------MAC-Adresse des ENC28J60 lesen--------------------*/
void enc28j60GetMacAddr(unsigned char *macaddr)
{
	enc28j60Read(MAADR1, (macaddr+0));
	enc28j60Read(MAADR2, (macaddr+1));
	enc28j60Read(MAADR3, (macaddr+2));
	enc28j60Read(MAADR4, (macaddr+3));
	enc28j60Read(MAADR5, (macaddr+4));
	enc28j60Read(MAADR6, (macaddr+5));
}

/*--------------------Verndern der MAC-Adresse des ENC28J60--------------------*/
void enc28j60SetMacAddr(unsigned char *macaddr)
{
   

	enc28j60Write(MAADR1, *(macaddr+0));
	enc28j60Write(MAADR2, *(macaddr+1));
	enc28j60Write(MAADR3, *(macaddr+2));
	enc28j60Write(MAADR4, *(macaddr+3));
	enc28j60Write(MAADR5, *(macaddr+4));
	enc28j60Write(MAADR6, *(macaddr+5));	

}

/*--------------------System Reset des ENC28J60--------------------*/
void enc28j60SysReset()
{
	SELECT();						//CS auf '0'	
	spi1_data(SYSTEM_RESET_CMD);	//0xff an ENC28J60 schicken --> System Reset
	DSELECT();						//CS auf '1'
}

/*--------------------Inhalt eines PHY-Registers verndern--------------------*/
void enc28j60WritePhyReg(unsigned char address, unsigned short daten)
{
	enc28j60Write(MIREGADR, address);	//Adresse des PHY-Registers in "spezielles" Register schreiben
	enc28j60Write(MIWRL, daten);		//Daten fr das PHY-Register in "spezielles" Register schreiben
	enc28j60Write(MIWRH, daten>>8);

	wait_10us();
	wait_10us();
	wait_10us();

	do
	{
		enc28j60Read(MISTAT, &hilf);
	}
	while(hilf & MISTAT_BUSY);	//ist Schreibvorgang schon abgeschlossen?
}

/*--------------------Inhalt eines PHY-Registers auslesen--------------------*/
void enc28j60ReadPhyReg(unsigned char address, unsigned char *testdata1, unsigned char *testdata2)
{
	enc28j60Write(MIREGADR, address);	//Adresse des PHY-Registers in "spezielles" Register schreiben
	
	enc28j60Read(MICMD, &hilf);		//Inhalt von MICMD lesen
	hilf |= MICMD_MIIRD;			//Daten aus PHY-Register lesen
	enc28j60Write(MICMD, hilf);		//Verndern von MICMD

	wait_10us();
	wait_10us();
	wait_10us();

	do
	{
		enc28j60Read(MISTAT, &hilf);
	}
	while(hilf & MISTAT_BUSY);	//ist Lesevorgang schon abgeschlossen?
	
	enc28j60Read(MICMD, &hilf);		//Inhalt von MICMD lesen
	hilf &= ~MICMD_MIIRD;			//Daten aus PHY-Register lesen
	enc28j60Write(MICMD, hilf);		//Verndern von MICMD	
}

/*--------------------Inhalt eines Registers lesen--------------------*/
void enc28j60Read(unsigned char address, unsigned char* daten)
{
	enc28j60SelBank(address);				//Registerbank auswhlen (ersten 2 Bit von address)
	enc28j60ReadCTRLreg(address, daten);	//Inhalt des Registers [address] lesen und in [daten] schreiben
}

/*--------------------In ein Register schreiben--------------------*/
void enc28j60Write(unsigned char address, unsigned char daten)
{
	enc28j60SelBank(address);				//Registerbank auswhlen (ersten 2 Bit von address)
	enc28j60WriteCTRLreg(address, daten);	//[daten] in das Register [address] schreiben
}

/*--------------------Inhalt eines Registers lesen--------------------*/
//!!!Registerbank muss schon ausgewhlt sein!!!
void enc28j60ReadCTRLreg(unsigned char address, unsigned char* daten)
{
	real_address = 0x00;
	real_address |= READ_CTRL_REG;			//OpCode (ersten 3 Bit) = Read Control Register 
	real_address |= (address&ADDR_MASK);	//Argument (letzten 5 Bit) = Adresse
	
	SELECT();
	wait_10us();					//CS auf '0'
	spi1_data(real_address);		//Befehl an ENC28J60 schicken
	if(address&USE_DUMMY)			//Bei MAC oder MII Register -> zuerst Dummy Byte lesen
	{
		spi1_data(0x00);
	}
	*daten = spi1_data(0x00);		//Daten lesen
	wait_10us();				
	DSELECT();						//CS auf '1'
}

/*--------------------In ein Register schreiben--------------------*/
//!!!Registerbank muss schon ausgewhlt sein!!!
void enc28j60WriteCTRLreg(unsigned char address, unsigned char daten)
{
	real_address = 0x00;	
	real_address |= WRITE_CTRL_REG;			//OpCode (ersten 3 Bits) = Write Control Reigster
	real_address |= (address&ADDR_MASK);	//Argument (letzten 5 Bits) = Adresse

	SELECT();					//CS auf '0'
	wait_10us();
	spi1_data(real_address);	//Befehl an ENC28J60 schicken
	spi1_data(daten);			//Daten an ENC28J60 schicken
	wait_10us();
	DSELECT();					//CS auf '1'
}

/*--------------------Eine Registerbank auswhlen--------------------*/
void enc28j60SelBank(unsigned char address)
{
	unsigned char new_bank=0x00;
	hilf=0x00;
	
	new_bank = address&BANK_MASK;
	if(new_bank != enc28j60CurrentBank)			//Nur wenn die gewnschte Bank nicht schon ausgewhlt ist
	{	
		enc28j60ReadCTRLreg(ECON1, &hilf);		//ECON1 Register lesen
		hilf &= (~(ECON1_BSEL0|ECON1_BSEL1));	//Bits fr whlen der Registerbank lschen		
		hilf |= (new_bank)>>6; 					//ersten 2 Bit maskieren und auf letzten 2 Bits setzen (Registerbank whlen)
		enc28j60WriteCTRLreg(ECON1, hilf);		//ECON1 Register verndern (Bank auswhlen)
		
		enc28j60CurrentBank=(new_bank);			//ausgewhlte Bank speichern
	}
}


//Bit Set Operation
//Set a bit in a specific register
void enc28j60BitSet(unsigned char address, unsigned char daten)
{
	unsigned char opcode=0x00;
	
	opcode|=BIT_FIELD_SET;
	opcode|=(address&ADDR_MASK);
	
	SELECT();
	spi1_data(opcode);
	spi1_data(daten);
	DSELECT();
}

//Bit clear operation
void enc28j60BitClr(unsigned char address, unsigned char daten)
{
	unsigned char opcode=0x00;
	
	opcode|=BIT_FIELD_CLR;
	opcode|=(address&ADDR_MASK);
	
	SELECT();
	spi1_data(opcode);
	spi1_data(daten);
	DSELECT();
}

void enc28j60PacketSend(unsigned int len, unsigned char* packet)
{
	//Set the write pointer to start of transmit buffer area
	enc28j60Write(EWRPTL, TXSTART_INIT);
	enc28j60Write(EWRPTH, TXSTART_INIT>>8);
	
	//Set the TXND pointer to corresponnd to the packet size given
	enc28j60Write(ETXNDL, (TXSTART_INIT+len));
	enc28j60Write(ETXNDH, (TXSTART_INIT+len)>>8);
	
	enc28j60WriteBufferMem(len, packet);
	
	//send the contents of the transmit buffer onto the network
	enc28j60BitSet(ECON1, ECON1_TXRTS);
}

unsigned int enc28j60PacketReceive(unsigned int maxlen, unsigned char* packet)
{
	unsigned short rxstat;
	unsigned short len;
	unsigned char daten;
	//unsigned int i;
	
	//check if a packet has been received and buffered
	enc28j60Read(EIR, &daten);
	if(!(daten&EIR_PKTIF)) return 0;
	
	//SET the read pointer to the start of the received packet, ECON2_AUTOINC is default set
	enc28j60Write(ERDPTL, (NextPacketPtr));
	enc28j60Write(ERDPTH, (NextPacketPtr)>>8);
	
	//read the next packet pointer
	enc28j60ReadBufferMem(1, &daten);
	NextPacketPtr=daten;
	enc28j60ReadBufferMem(1, &daten);
	NextPacketPtr|=daten<<8;
	
	//read the packet length
	enc28j60ReadBufferMem(1, &daten);
	len=daten;
	enc28j60ReadBufferMem(1, &daten);
	len|=daten<<8;

	//read the receive status
	enc28j60ReadBufferMem(1, &daten);
	rxstat=daten;
	enc28j60ReadBufferMem(1, &daten);
	rxstat|=daten<<8;

	//limit retrieve length
	//reduce the MAC-reported length by 4 to remove the CRC
	len=MIN(len, maxlen);
	
	//copy the packet from the receive buffer
	enc28j60ReadBufferMem(len, packet);
	
	//Move the RX read pointer to the start of the next received packet
	//This frees the memory we just read out
	enc28j60Write(ERXRDPTL, (NextPacketPtr));
	enc28j60Write(ERXRDPTH, (NextPacketPtr)>>8);
	
	//decrement the packet counter indicate we are done with this packet
	enc28j60BitSet(ECON2, ECON2_PKTDEC);
	
	return len;
}

//Read Buffer
void enc28j60ReadBufferMem(unsigned short len, unsigned char* daten)
{
	unsigned char opcode;
	opcode=READ_BUFF_MEM;
	
	SELECT();
	wait_10us();
	spi1_data(opcode);
	while(len--)
	{
		*daten = spi1_data(0x00);
		 daten++;
	}
	wait_10us();
	DSELECT();
}

//Write Buffer
void enc28j60WriteBufferMem(unsigned short len, unsigned char* daten)
{
	unsigned char opcode;
	opcode=WRITE_BUFF_MEM;
	
	SELECT();
	wait_10us();
	spi1_data(opcode);
	spi1_data(0x00);

	while(len--)
	{	

		

		spi1_data(*daten);
		daten++;
		//len--;
	}

	wait_10us();
	DSELECT();
}
